@@ -27,7 +27,7 @@
 class Speed : public Lum::Control
 {
 private:
-  Lum::Model::DoubleRef model;
+  Lum::Model::NumberRef model;
 
 public:
   Speed();
